@@ -82,6 +82,18 @@ pub enum FileError {
         min_version: String,
     },
 
+    /// Remedy: restart.
+    #[cfg(not(test))]
+    #[error(
+        "Configuration file error in section `[filename]`:\n\
+        `sort_tag_chars=\"{chars}\"` must not contain:\n\
+        `sort_tag_extra_separator=\"{extra_separator}\"`"
+    )]
+    ConfigFileSortTag {
+        chars: String,
+        extra_separator: String,
+    },
+
     /// Should not happen. Please report this bug.
     #[error("No path to configuration file found.")]
     PathToConfigFileNotFound,
@@ -250,11 +262,14 @@ pub enum NoteError {
         "The `sort_tag` header variable contains invalid \
          character(s):\n\n\
          \t---\n\
-         \tsort_tag = \"{sort_tag}\".\n\
+         \tsort_tag = \"{sort_tag}\"\n\
          \t---\n\n\
-         Only numbers, `-` and `_` are allowed here."
+         Only the characters: \"{sort_tag_chars}\" are allowed here."
     )]
-    SortTagVarInvalidChar { sort_tag: String },
+    SortTagVarInvalidChar {
+        sort_tag: String,
+        sort_tag_chars: String,
+    },
 
     /// Remedy: correct the front matter variable `file_ext`.
     #[error(
@@ -263,7 +278,7 @@ pub enum NoteError {
         \tfile_ext=\"{extension}\"\n\
         \t---\n\
         is not registered as a valid\n\
-        Tp-Note-file in the `note_file_extensions.*` variables\n\
+        Tp-Note-file in the `[filename] extensions_*` variables\n\
         in your configuration file:\n\
         \t{md_ext:?}\n\
         \t{rst_ext:?}\n\
@@ -272,7 +287,7 @@ pub enum NoteError {
         \t{no_viewer_ext:?}\n\
         \n\
         Choose one of the above list or add more extensions to the\n\
-        `note_file_extensions.*` variables in your configuration file."
+        `[filename] extensions_*` variables in your configuration file."
     )]
     FileExtNotRegistered {
         extension: String,
